Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: include/v8.h

Issue 6672044: [Isolates] Fix debugger and termination APIs callable from other threads. (Closed) Base URL: https://v8.googlecode.com/svn/branches/experimental/isolates
Patch Set: Address comments. Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | include/v8-debug.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8.h
diff --git a/include/v8.h b/include/v8.h
index 9a8c59c1e674bc01664da26c90ca5aa8b70b524d..c6901e2b984417c463d01b58b2f9e4b0f4316f6c 100644
--- a/include/v8.h
+++ b/include/v8.h
@@ -2943,12 +2943,16 @@ class V8EXPORT V8 {
static void TerminateExecution(int thread_id);
/**
* Forcefully terminate the current thread of JavaScript execution.
*
* This method can be used by any thread even if that thread has not
* acquired the V8 lock with a Locker object.
+ *
+ * \param isolate The isolate in which to terminate the current JS execution.
*/
- static void TerminateExecution();
+ static void TerminateExecution(Isolate* isolate = NULL);
/**
* Is V8 terminating JavaScript execution.
« no previous file with comments | « no previous file | include/v8-debug.h » ('j') | no next file with comments »
@@ -2943,12 +2943,16 @@ class V8EXPORT V8 {
static void TerminateExecution(int thread_id);
/**
- * Forcefully terminate the current thread of JavaScript execution.
+ * Forcefully terminate the current thread of JavaScript execution
+ * in the given isolate. If no isolate is provided, the default
+ * isolate is used.
*
* This method can be used by any thread even if that thread has not

Powered by Google App Engine
This is Rietveld 408576698